==> xmule_1.8.2b.orig.tar.gz: xmule-1.8.2b/src/xmule-headers.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
//
// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
//
//This program is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either
//version 2 of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef _xmule_headers_h
#define _xmule_headers_h
#include "syspch.h"
#include "resource.h"
#include "AddFileThread.h"
#include "AddFriend.h"
#include "BarShader.h"
#include "CFile.h"
#include "CMemFile.h"
#include "CMuleNotebookBase.h"
#include "CatDialog.h"
#include "ChatWnd.h"
#include "ClientCredits.h"
#include "ClientDetailDialog.h"
#include "ClientList.h"
#include "ClientUDPSocket.h"
#include "ColorFrameCtrl.h"
#include "CommentDialog.h"
#include "CommentDialogLst.h"
#include "DirectoryTreeCtrl.h"
#include "DownloadListCtrl.h"
#include "DownloadQueue.h"
#include "ED2KLink.h"
#include "EMSocket.h"
#include "EMSocketL.h"
#include "EditServerListDlg.h"
#include "FileDetailDialog.h"
#include "Friend.h"
#include "FriendList.h"
#include "FriendListCtrl.h"
#include "HTTPDownloadDlg.h"
#include "IPFilter.h"
#include "KnownFile.h"
#include "KnownFileList.h"
#include "ListenSocket.h"
#include "MD5Sum.h"
#include "MapKey.h"
#include "MuleListCtrl.h"
#include "MuleNotebook.h"
#include "OScopeCtrl.h"
#include "PPgConnection.h"
#include "PPgDirectories.h"
#include "PPgFiles.h"
#include "PPgGeneral.h"
#include "PPgGuiTweaks.h"
#include "PPgIrc.h"
#include "PPgNotify.h"
#include "PPgServer.h"
#include "PPgSourcesDropping.h"
#include "PPgStats.h"
#include "PPgTweaks.h"
#include "PartFile.h"
#include "Preferences.h"
#include "PreferencesDlg.h"
#include "Preview.h"
#include "QueueListCtrl.h"
//#include "RazorPreferencesDlg.h"
//#include "RazorPreferencesDlg_wdr.h"
#include "SafeFile.h"
#include "SearchDlg.h"
#include "SearchList.h"
#include "ServerList.h"
#include "ServerSocket.h"
#include "ServerWnd.h"
#include "SharedFileList.h"
#include "SharedFilesCtrl.h"
#include "SharedFilesWnd.h"
#include "SplitterControl.h"
#include "StatisticsDlg.h"
#include "SysTray.h"
#include "TabCtrl.h"
#include "TransferWnd.h"
#include "UDPSocket.h"
#include "UploadListCtrl.h"
#include "UploadQueue.h"
#include "WebServer.h"
#include "WebSocket.h"
#include "Wizard.h"
#include "XBMDraw.h"
#include "animate.h"
#include "config.h"
#include "eggtrayicon.h"
#include "gsocket.h"
#include "gsockunx.h"
#include "gtk2-funcs.h"
#include "gtkplugxembed.h"
#include "ini2.h"
#include "listbase.h"
#include "listctrl.h"
#include "listctrl_gen.h"
#include "listctrl_new.h"
#include "mfc.h"
#include "mmMultiButton.h"
#include "muuli_wdr.h"
#include "opcodes.h"
#include "otherfunctions.h"
#include "otherstructs.h"
#include "packets.h"
#include "resource.h"
#include "server.h"
#include "sockets.h"
#include "treebasc.h"
#include "treectlc.h"
#include "treectrl.h"
#include "types.h"
#include "updownclient.h"
#include "wintypes.h"
#include "xmule.h"
#include "xmuleDlg.h"
#include "FlowChart.h"
#endif

==> xmule_1.10.0b.orig.tar.gz: xmule-1.10.0b.orig/src/xmule-headers.h <==

// This file is a part of the xMule Project.
//
// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef _xmule_headers_h
#define _xmule_headers_h

#include "resource.h"
#include "AddFileThread.h"
#include "AddFriend.h"
#include "BarShader.h"
#include "CFile.h"
#include "CMemFile.h"
#include "CatDialog.h"
#include "ChatWnd.h"
#include "ClientCredits.h"
#include "ClientDetailDialog.h"
#include "ClientList.h"
#include "ClientUDPSocket.h"
#include "ColorFrameCtrl.h"
#include "CommentDialog.h"
#include "CommentDialogLst.h"
#include "CryptoXMpp.h"
#include "DirectoryTreeCtrl.h"
#include "DownloadListCtrl.h"
#include "DownloadQueue.h"
#include "ED2KLink.h"
#include "EMSocket.h"
#include "EditServerListDlg.h"
#include "FileDetailDialog.h"
#include "Friend.h"
#include "FriendList.h"
#include "FriendListCtrl.h"
#include "HTTPDownloadDlg.h"
#include "IPFilter.h"
#include "KnownFile.h"
#include "KnownFileList.h"
#include "ListenSocket.h"
#include "MD5Sum.h"
#include "MapKey.h"
#include "MuleListCtrl.h"
#include "MuleNotebook.h"
#include "NewFunctions.h"
#include "NewSockets.h"
#include "OScopeCtrl.h"
#include "PPgConnection.h"
#include "PPgDirectories.h"
#include "PPgFiles.h"
#include "PPgGeneral.h"
#include "PPgNotify.h"
#include "PPgServer.h"
#include "PPgSourcesDropping.h"
#include "PPgStats.h"
#include "PPgTweaks.h"
#include "PartFile.h"
#include "Preferences.h"
#include "PreferencesDlg.h"
#include "Preview.h"
#include "QueueListCtrl.h"
#include "SafeFile.h"
#include "SearchDlg.h"
#include "SearchList.h"
#include "ServerList.h"
#include "ServerSocket.h"
#include "ServerWnd.h"
#include "SharedFileList.h"
#include "SharedFilesCtrl.h"
#include "SharedFilesWnd.h"
#include "StatisticsDlg.h"
#include "SysTray.h"
#include "TransferWnd.h"
#include "UDPSocket.h"
#include "UploadListCtrl.h"
#include "UploadQueue.h"
#include "Wizard.h"
#include "XBMDraw.h"
#include "animate.h"
#include "config.h"
#include "eggtrayicon.h"
#include "gsocket.h"
#include "gsockunx.h"
#include "gtk2-funcs.h"
#include "gtkplugxembed.h"
#include "ini2.h"
#include "ldaemon.h"
#include "listctrl.h"
#include "mfc.h"
#include "muuli_wdr.h"
#include "opcodes.h"
#include "otherfunctions.h"
#include "otherstructs.h"
#include "packets.h"
#include "resource.h"
#include "server.h"
#include "sockets.h"
#include "treebasc.h"
#include "treectlc.h"
#include "treectrl.h"
#include "updownclient.h"
#include "wintypes.h"
#include "xmule.h"
#include "xmuleDlg.h"
#include "FlowChart.h"
#endif
